@@ -16,7 +16,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "../../config.h"
 #endif
 
 #include <stdlib.h>
@@ -52,22 +52,20 @@ static int pcap_fd = -1;
 static inline void *xmalloc(size_t sz)
 {
   void *p = malloc(sz);
-  if (!p)
-    {
-      perror("malloc failure");
-      abort();
-    }
+  if (!p) {
+    perror("malloc failure");
+    abort();
+  }
   return p;
 }
 
 static inline char *xstrdup(const char *s)
 {
   char *new = strdup(s);
-  if (!new)
-    {
-      perror("strdup failure");
-      abort();
-    }
+  if (!new) {
+    perror("strdup failure");
+    abort();
+  }
   return new;
 }
 
@@ -76,27 +74,25 @@ static inline void xfree(void *p)
   free(p);
 }
 
-#define __xmessage(pfx, fmt, ...) fprintf(stderr, pfx": "fmt"\n", ##__VA_ARGS__)
-#define xwarning(fmt, ...) __xmessage("warning", fmt, ##__VA_ARGS__)
-#define xerror(fmt, ...) __xmessage("error", fmt, ##__VA_ARGS__)
-#define xcritical(fmt, ...) __xmessage("critical", fmt, ##__VA_ARGS__)
+#define __xmessage(pfx, fmt, ...)  fprintf(stderr, pfx ": "fmt "\n", ## __VA_ARGS__)
+#define xwarning(fmt, ...)         __xmessage("warning", fmt, ## __VA_ARGS__)
+#define xerror(fmt, ...)           __xmessage("error", fmt, ## __VA_ARGS__)
+#define xcritical(fmt, ...)        __xmessage("critical", fmt, ## __VA_ARGS__)
 
 static inline void ctrl_send(const void *buf, size_t len)
 {
-  if (write_all(ctrlsock, buf, len))
-    {
-      xcritical("write_all() failed on control socket");
-      exit(1);
-    }
+  if (write_all(ctrlsock, buf, len)) {
+    xcritical("write_all() failed on control socket");
+    exit(1);
+  }
 }
 
 static inline void ctrl_recv(void *buf, size_t len)
 {
-  if (read_all(ctrlsock, buf, len))
-    {
-      xcritical("read_all() failed on control socket");
-      exit(1);
-    }
+  if (read_all(ctrlsock, buf, len)) {
+    xcritical("read_all() failed on control socket");
+    exit(1);
+  }
 }
 
 static inline void sendresp(const struct capctl_resp_t *resp)
@@ -155,11 +151,10 @@ static void handle_listdevs(const struct capctl_req_t *req)
   zeroresp(&resp);
 
   status = pcap_findalldevs(&alldevs, errbuf);
-  if (status != 0)
-    {
-      senderrmsg(errbuf);
-      return;
-    }
+  if (status != 0) {
+    senderrmsg(errbuf);
+    return;
+  }
 
   resp.listdevs.len = 0;
 
@@ -181,7 +176,7 @@ static void handle_listdevs(const struct capctl_req_t *req)
 }
 
 /* TODO: screen refresh rate? */
-#define PCAP_TIMEOUT 250
+#define PCAP_TIMEOUT  250
 
 static void handle_startcap(const struct capctl_req_t *req)
 {
@@ -191,42 +186,37 @@ static void handle_startcap(const struct capctl_req_t *req)
 
   zeroresp(&resp);
 
-  if (pcap)
-    {
-      senderrmsg("capture already running");
-      return;
-    }
+  if (pcap) {
+    senderrmsg("capture already running");
+    return;
+  }
 
-  if (!req->startcap.devlen)
-    {
-      devname = pcap_lookupdev(errbuf);
-      if (!devname)
-        {
-          senderrmsg(errbuf);
-          return;
-        }
-      devname = xstrdup(devname);
-    }
-  else
-      devname = recvstr(req->startcap.devlen);
-
-  pcap = pcap_open_live(devname, MAXCAPSIZE, 1, PCAP_TIMEOUT, errbuf);
-  if (!pcap)
-    {
-      xfree(devname);
+  if (!req->startcap.devlen) {
+    devname = pcap_lookupdev(errbuf);
+    if (!devname) {
       senderrmsg(errbuf);
       return;
     }
+    devname = xstrdup(devname);
+  }
+  else
+    devname = recvstr(req->startcap.devlen);
+
+  pcap = pcap_open_live(devname, MAXCAPSIZE, 1, PCAP_TIMEOUT, errbuf);
+  if (!pcap) {
+    xfree(devname);
+    senderrmsg(errbuf);
+    return;
+  }
 
   pcap_fd = pcap_get_selectable_fd(pcap);
-  if (pcap_fd < 0)
-    {
-      senderrmsg("failed to get selectable pcap fd");
-      xfree(devname);
-      pcap_close(pcap);
-      pcap = NULL;
-      return;
-    }
+  if (pcap_fd < 0) {
+    senderrmsg("failed to get selectable pcap fd");
+    xfree(devname);
+    pcap_close(pcap);
+    pcap = NULL;
+    return;
+  }
 
   if (pcap_setnonblock(pcap, 1, errbuf) == -1)
     xwarning("Failed to set pcap nonblocking: %s", errbuf);
@@ -248,32 +238,29 @@ static void handle_setfilter(const struct capctl_req_t *req)
 
   zeroresp(&resp);
 
-  if (!pcap)
-    {
-      senderrmsg("no pcap device started");
-      return;
-    }
-
   bpfstr = recvstr(req->setfilter.bpflen);
 
+  if (!pcap) {
+    senderrmsg("no pcap device started");
+    return;
+  }
+
   /* TODO: netmask? */
   status = pcap_compile(pcap, &bpfprog, bpfstr, 1, PCAP_NETMASK_UNKNOWN);
   xfree(bpfstr);
 
-  if (status)
-    {
-      senderrmsg(pcap_geterr(pcap));
-      return;
-    }
+  if (status) {
+    senderrmsg(pcap_geterr(pcap));
+    return;
+  }
 
   status = pcap_setfilter(pcap, &bpfprog);
   pcap_freecode(&bpfprog);
 
-  if (status)
-    {
-      senderrmsg(pcap_geterr(pcap));
-      return;
-    }
+  if (status) {
+    senderrmsg(pcap_geterr(pcap));
+    return;
+  }
 
   resp.status = CRP_OK;
   sendresp(&resp);
@@ -285,17 +272,15 @@ static void handle_getstats(const struct capctl_req_t *req)
 
   zeroresp(&resp);
 
-  if (!pcap)
-    {
-      senderrmsg("no pcap device started");
-      return;
-    }
+  if (!pcap) {
+    senderrmsg("no pcap device started");
+    return;
+  }
 
-  if (pcap_stats(pcap, &resp.getstats.stats))
-    {
-      senderrmsg(pcap_geterr(pcap));
-      return;
-    }
+  if (pcap_stats(pcap, &resp.getstats.stats)) {
+    senderrmsg(pcap_geterr(pcap));
+    return;
+  }
 
   resp.status = CRP_OK;
   sendresp(&resp);
@@ -303,32 +288,30 @@ static void handle_getstats(const struct capctl_req_t *req)
 
 static void handle_stopcap(const struct capctl_req_t *req)
 {
-  if (pcap)
-    {
-      pcap_close(pcap);
-      pcap = NULL;
-      pcap_fd = -1;
-      sendok();
-    }
+  if (pcap) {
+    pcap_close(pcap);
+    pcap = NULL;
+    pcap_fd = -1;
+    sendok();
+  }
   else
     senderrmsg("already stopped");
 }
 
 static void handle_exit(const struct capctl_req_t *req)
 {
-  if (pcap)
-    {
-      pcap_close(pcap);
-      pcap = NULL;
-      pcap_fd = -1;
-    }
+  if (pcap) {
+    pcap_close(pcap);
+    pcap = NULL;
+    pcap_fd = -1;
+  }
   sendok();
   close(ctrlsock);
   close(pktpipe);
   exit(0);
 }
 
-static void (*const handlers[])(const struct capctl_req_t*) = {
+static void (*const handlers[])(const struct capctl_req_t *) = {
   [CRQ_PING] = handle_ping,
   [CRQ_LISTDEVS] = handle_listdevs,
   [CRQ_STARTCAP] = handle_startcap,
@@ -345,11 +328,10 @@ static void handle_ctrlmsg(void)
   ctrl_recv(&req, sizeof(req));
   if (req.type < sizeof(handlers)/sizeof(handlers[0]) && handlers[req.type])
     handlers[req.type](&req);
-  else
-    {
-      xcritical("unknown request type %d", req.type);
-      exit(1);
-    }
+  else {
+    xcritical("unknown request type %d", req.type);
+    exit(1);
+  }
 }
 
 /* Single-packet in-memory buffer in case pktpipe blocks */
@@ -368,25 +350,21 @@ static void flush_pktbuf(void)
 
   assert(pktbuf.offset < pktbuf.buffered);
 
-  while (pktbuf.offset < pktbuf.buffered)
-    {
-      status = write(pktpipe, pktbuf.buf + pktbuf.offset,
-                     pktbuf.buffered - pktbuf.offset);
-      if (status < 0)
-        {
-          if (errno == EAGAIN || errno == EWOULDBLOCK)
-            return;
-          else
-            {
-              perror("pktpipe write(2) failed");
-              abort();
-            }
-        }
-      else
-        {
-          pktbuf.offset += status;
-        }
+  while (pktbuf.offset < pktbuf.buffered) {
+    status = write(pktpipe, pktbuf.buf + pktbuf.offset,
+                   pktbuf.buffered - pktbuf.offset);
+    if (status < 0) {
+      if (errno == EAGAIN || errno == EWOULDBLOCK)
+        return;
+      else {
+        perror("pktpipe write(2) failed");
+        abort();
+      }
     }
+    else {
+      pktbuf.offset += status;
+    }
+  }
   pktbuf.buffered = pktbuf.offset = 0;
 }
 
@@ -399,16 +377,15 @@ static void handle_packet(void)
   assert(pktbuf.buffered == 0);
 
   status = pcap_next_ex(pcap, &hdr, &data);
-  if (status == 1)
-    {
-      pktbuf.buffered = sizeof(*hdr) + hdr->caplen;
-      assert(pktbuf.buffered <= sizeof(pktbuf.buf));
+  if (status == 1) {
+    pktbuf.buffered = sizeof(*hdr) + hdr->caplen;
+    assert(pktbuf.buffered <= sizeof(pktbuf.buf));
 
-      memcpy(pktbuf.buf, hdr, sizeof(*hdr));
-      memcpy(pktbuf.buf + sizeof(*hdr), data, hdr->caplen);
+    memcpy(pktbuf.buf, hdr, sizeof(*hdr));
+    memcpy(pktbuf.buf + sizeof(*hdr), data, hdr->caplen);
 
-      flush_pktbuf();
-    }
+    flush_pktbuf();
+  }
   else if (status < 0)
     xerror("pcap_next_ex failed: %s", pcap_geterr(pcap));
 }
@@ -424,45 +401,40 @@ void pktcap_run(int csockfd, int ppipefd)
   set_fd_nonblock(ctrlsock, 1);
   set_fd_nonblock(pktpipe, 1);
 
-  for (;;)
-    {
-      FD_ZERO(&rfds);
-      FD_ZERO(&wfds);
-      maxfd = -1;
+  for (;;) {
+    FD_ZERO(&rfds);
+    FD_ZERO(&wfds);
+    maxfd = -1;
 
-      FD_SET(ctrlsock, &rfds);
-      maxfd = maxfd > ctrlsock ? maxfd : ctrlsock;
+    FD_SET(ctrlsock, &rfds);
+    maxfd = maxfd > ctrlsock ? maxfd : ctrlsock;
 
-      if (pcap_fd >= 0)
-        {
-          FD_SET(pcap_fd, &rfds);
-          maxfd = maxfd > pcap_fd ? maxfd : pcap_fd;
-        }
-
-      if (pktbuf.buffered > 0)
-        {
-          FD_SET(pktpipe, &wfds);
-          maxfd = maxfd > pktpipe ? maxfd : pktpipe;
-        }
-
-      status = select(maxfd+1, &rfds, &wfds, NULL, NULL);
-      if (status < 0)
-        {
-          xcritical("capture-loop select() failed");
-          exit(1);
-        }
-
-      if (FD_ISSET(pktpipe, &wfds))
-        flush_pktbuf();
-
-      if (FD_ISSET(ctrlsock, &rfds))
-        {
-          set_fd_nonblock(ctrlsock, 0);
-          handle_ctrlmsg();
-          set_fd_nonblock(ctrlsock, 1);
-        }
-
-      if (pcap_fd >= 0 && FD_ISSET(pcap_fd, &rfds) && pktbuf.buffered == 0)
-        handle_packet();
+    if (pcap_fd >= 0) {
+      FD_SET(pcap_fd, &rfds);
+      maxfd = maxfd > pcap_fd ? maxfd : pcap_fd;
     }
+
+    if (pktbuf.buffered > 0) {
+      FD_SET(pktpipe, &wfds);
+      maxfd = maxfd > pktpipe ? maxfd : pktpipe;
+    }
+
+    status = select(maxfd+1, &rfds, &wfds, NULL, NULL);
+    if (status < 0) {
+      xcritical("capture-loop select() failed");
+      exit(1);
+    }
+
+    if (FD_ISSET(pktpipe, &wfds))
+      flush_pktbuf();
+
+    if (FD_ISSET(ctrlsock, &rfds)) {
+      set_fd_nonblock(ctrlsock, 0);
+      handle_ctrlmsg();
+      set_fd_nonblock(ctrlsock, 1);
+    }
+
+    if (pcap_fd >= 0 && FD_ISSET(pcap_fd, &rfds) && pktbuf.buffered == 0)
+      handle_packet();
+  }
 }
