@@ -1,7 +1,7 @@
 /* EtherApe
  * Copyright (C) 2000 Juan Toledo
  * Copyright (C) 2011 Riccardo Ghetta
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -20,7 +20,7 @@
 #define PREFERENCES_H
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "../config.h"
 #endif
 #include "common.h"
 
@@ -32,26 +32,26 @@
  */
 struct pref_struct
 {
-  gboolean name_res;		/* Whether dns lookups are performed */
-  gboolean diagram_only;	/* Do not use text on the diagram */
-  gboolean group_unk;		/* Whether to display as one every unkown port protocol */
-  gdouble node_radius_multiplier;	/* used to calculate the radius of the
-					 * displayed nodes. So that the user can
-					 * select with certain precision this
-					 * value, the GUI uses the log10 of the
-					 * multiplier */
-  gdouble link_node_ratio;	/* link width to node radius ratio */
+  gboolean name_res;            /* Whether dns lookups are performed */
+  gboolean diagram_only;        /* Do not use text on the diagram */
+  gboolean group_unk;           /* Whether to display as one every unkown port protocol */
+  gdouble node_radius_multiplier;       /* used to calculate the radius of the
+                                         * displayed nodes. So that the user can
+                                         * select with certain precision this
+                                         * value, the GUI uses the log10 of the
+                                         * multiplier */
+  gdouble link_node_ratio;      /* link width to node radius ratio */
   gdouble inner_ring_scale; /* scale of inner ring in proportion to outer ring */
-  size_mode_t size_mode;	/* Default mode for node size and
-				 * link width calculation */
-  node_size_variable_t node_size_variable;	/* Default variable that sets the node
-						 * size */
-  gchar *filter;		/* Pcap filter to be used */
-  gchar *text_color;		/* text color */
-  gchar *fontname;		/* Font to be used for text display */
+  size_mode_t size_mode;        /* Default mode for node size and
+                                 * link width calculation */
+  node_size_variable_t node_size_variable;      /* Default variable that sets the node
+                                                 * size */
+  gchar *filter;                /* Pcap filter to be used */
+  gchar *text_color;            /* text color */
+  gchar *fontname;              /* Font to be used for text display */
   gchar *centered_nodes;        /* Name/IP/CIDR-range of nodes to center (optional) */
-  guint stack_level;		/* Which level of the protocol stack 
-				 * we will concentrate on */
+  guint stack_level;            /* Which level of the protocol stack
+                                 * we will concentrate on */
 
   gboolean bck_image_enabled; /* Whether or not to use a background image */
   gchar *bck_image_path;    /* Path to the background image (optional) */
@@ -67,11 +67,11 @@ struct pref_struct
    * from the global protocol stats */
   gdouble proto_timeout_time;
 
-  /* After this time has passed with no traffic for a node, it 
+  /* After this time has passed with no traffic for a node, it
    * disappears from the diagram */
   gdouble gui_node_timeout_time;
 
-  /* After this time has passed with no traffic for a node, it 
+  /* After this time has passed with no traffic for a node, it
   * is deleted from memory */
   gdouble node_timeout_time;
 
@@ -79,15 +79,15 @@ struct pref_struct
    * from the node protocol stats */
   gdouble proto_node_timeout_time;
 
-  gchar **colors;       /* list of colors to be used on the diagram. Format is
-			 * color[;protocol[,protocol ...]] [color[;protocol] ...
-			 * where color is represented by sis hex digits (RGB) */
+  gchar * *colors;       /* list of colors to be used on the diagram. Format is
+                         * color[;protocol[,protocol ...]] [color[;protocol] ...
+                         * where color is represented by sis hex digits (RGB) */
 
-  /* After this time has passed with no traffic for a link, it 
+  /* After this time has passed with no traffic for a link, it
    * disappears from the diagram */
   gdouble gui_link_timeout_time;
 
-  /* After this time has passed with no traffic for a link, it 
+  /* After this time has passed with no traffic for a link, it
   * is deleted from memory */
   gdouble link_timeout_time;
 
@@ -95,9 +95,9 @@ struct pref_struct
    * from the link protocol stats */
   gdouble proto_link_timeout_time;
 
-  guint32 refresh_period;	/* Time between diagram refreshes */
-  gdouble averaging_time;	/* Microseconds of time we consider to
-				 * calculate traffic averages */
+  guint32 refresh_period;       /* Time between diagram refreshes */
+  gdouble averaging_time;       /* Microseconds of time we consider to
+                                 * calculate traffic averages */
 };
 
 extern struct pref_struct pref;
