@@ -16,7 +16,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "../../config.h"
 #endif
 
 #include "appdata.h"
@@ -25,7 +25,7 @@
 #include "preferences.h"
 #include "conversations.h"
 
-static GTree *all_links = NULL;			/* Has all links heard on the net */
+static GTree *all_links = NULL;                 /* Has all links heard on the net */
 
 /***************************************************************************
  *
@@ -34,38 +34,35 @@ static GTree *all_links = NULL;			/* Has all links heard on the net */
  **************************************************************************/
 /* Comparison function used to order the (GTree *) links
  * and canvas_links heard on the network */
-gint
-link_id_compare (const link_id_t *a, const link_id_t *b)
+gint link_id_compare(const link_id_t *a, const link_id_t *b)
 {
   int i;
-  g_return_val_if_fail (a != NULL, 1);	/* This shouldn't happen.
-					 * We arbitrarily passing 1 to
-					 * the comparison */
-  g_return_val_if_fail (b != NULL, 1);
+  g_return_val_if_fail(a != NULL, 1);  /* This shouldn't happen.
+                                         * We arbitrarily passing 1 to
+                                         * the comparison */
+  g_return_val_if_fail(b != NULL, 1);
 
-  i = node_id_compare( &a->src, &b->src);
+  i = node_id_compare(&a->src, &b->src);
   if (i != 0)
     return i;
-  
-  return node_id_compare( &a->dst, &b->dst);
 
-}				/* link_id_compare */
+  return node_id_compare(&a->dst, &b->dst);
+}                               /* link_id_compare */
 
 /* returns a NEW gchar * with the node names of the link_id */
-gchar *
-link_id_node_names(const link_id_t *link_id)
+gchar *link_id_node_names(const link_id_t *link_id)
 {
   const node_t *src_node, *dst_node;
-  
+
   src_node = nodes_catalog_find(&link_id->src);
   dst_node = nodes_catalog_find(&link_id->dst);
-  if (!src_node || !dst_node || 
-    !src_node->name->str || !dst_node->name->str)
+  if (!src_node || !dst_node ||
+      !src_node->name->str || !dst_node->name->str)
     return g_strdup(""); /* invalid info */
 
   return g_strdup_printf("%s-%s",
-          src_node->name->str,
-          dst_node->name->str);
+                         src_node->name->str,
+                         dst_node->name->str);
 }
 
 
@@ -75,7 +72,7 @@ link_id_node_names(const link_id_t *link_id)
  * link_t implementation
  *
  **************************************************************************/
-static gint update_link(link_id_t * link_id, link_t * link, gpointer delete_list_ptr);
+static gint update_link(link_id_t *link_id, link_t *link, gpointer delete_list_ptr);
 
 /* creates a new link object */
 link_t *link_create(const link_id_t *link_id)
@@ -83,16 +80,15 @@ link_t *link_create(const link_id_t *link_id)
   link_t *link;
   guint i = STACK_SIZE;
 
-  link = g_malloc (sizeof (link_t));
+  link = g_malloc(sizeof(link_t));
   g_assert(link);
 
   link->link_id = *link_id;
 
-  while (i + 1)
-    {
-      link->main_prot[i] = NULL;
-      i--;
-    }
+  while (i + 1) {
+    link->main_prot[i] = NULL;
+    i--;
+  }
 
   traffic_stats_init(&link->link_stats);
 
@@ -107,19 +103,18 @@ void link_delete(link_t *link)
   g_assert(link);
 
   /* first, free any conversation belonging to the link */
-  delete_conversation_link (&link->link_id.src.addr.ip, 
-                            &link->link_id.dst.addr.ip);
-  
+  delete_conversation_link(&link->link_id.src.addr.ip,
+                           &link->link_id.dst.addr.ip);
+
   for (i = STACK_SIZE; i + 1; i--)
-    if (link->main_prot[i])
-      {
-        g_free (link->main_prot[i]);
-        link->main_prot[i] = NULL;
-      }
+    if (link->main_prot[i]) {
+      g_free(link->main_prot[i]);
+      link->main_prot[i] = NULL;
+    }
 
   traffic_stats_reset(&link->link_stats);
 
-  g_free (link);
+  g_free(link);
 }
 
 gchar *link_dump(const link_t *link)
@@ -138,18 +133,17 @@ gchar *link_dump(const link_t *link)
   msg_iddst = node_id_dump(&link->link_id.dst);
   msg_stats = traffic_stats_dump(&link->link_stats);
 
-  msg_mprot=g_strdup_printf("top: [%s], stack:", 
-                            (link->main_prot[0]) ? 
-                            link->main_prot[0] : "-none-");
-  
-  for (i = 1; i <= STACK_SIZE; i++)
-    {
-      gchar *tmp = msg_mprot;
-      msg_mprot = g_strdup_printf("%s %d:>%s<", msg_mprot, i, 
-                           (link->main_prot[i]) ? 
-                           link->main_prot[i] : "-none-");
-      g_free(tmp);
-    }
+  msg_mprot = g_strdup_printf("top: [%s], stack:",
+                              (link->main_prot[0]) ?
+                              link->main_prot[0] : "-none-");
+
+  for (i = 1; i <= STACK_SIZE; i++) {
+    gchar *tmp = msg_mprot;
+    msg_mprot = g_strdup_printf("%s %d:>%s<", msg_mprot, i,
+                                (link->main_prot[i]) ?
+                                link->main_prot[i] : "-none-");
+    g_free(tmp);
+  }
 
   msg = g_strdup_printf("src: %s, dst: %s, main_prot: [%s], stats [%s]",
                         msg_idsrc, msg_iddst, msg_mprot, msg_stats);
@@ -163,54 +157,46 @@ gchar *link_dump(const link_t *link)
 
 
 /* gfunc called by g_list_foreach to remove a link */
-static void
-gfunc_remove_link(gpointer data, gpointer user_data)
+static void gfunc_remove_link(gpointer data, gpointer user_data)
 {
-  links_catalog_remove( (const link_id_t *) data);
+  links_catalog_remove((const link_id_t *)data);
 }
 
-static gint
-update_link(link_id_t* link_id, link_t * link, gpointer delete_list_ptr)
+static gint update_link(link_id_t *link_id, link_t *link, gpointer delete_list_ptr)
 {
   double diffms;
 
   g_assert(delete_list_ptr);
 
   /* update stats - returns true if there are active packets */
-  if (traffic_stats_update(&link->link_stats, pref.averaging_time, 
-                            pref.proto_link_timeout_time))
-    {
-      /* packet(s) active, update the most used protocols for this link */
-      guint i = STACK_SIZE;
-      while (i + 1)
-        {
-          if (link->main_prot[i])
-            g_free (link->main_prot[i]);
-          link->main_prot[i]
-            = protocol_stack_sort_most_used(&link->link_stats.stats_protos, i);
-          i--;
-        }
+  if (traffic_stats_update(&link->link_stats, pref.averaging_time,
+                           pref.proto_link_timeout_time)) {
+    /* packet(s) active, update the most used protocols for this link */
+    guint i = STACK_SIZE;
+    while (i + 1) {
+      if (link->main_prot[i])
+        g_free(link->main_prot[i]);
+      link->main_prot[i] =
+        protocol_stack_sort_most_used(&link->link_stats.stats_protos, i);
+      i--;
+    }
+  }
+  else {
+    /* no packets remaining on link - if link expiration active, see if the
+     * link is expired */
+    if (pref.link_timeout_time) {
+      diffms = subtract_times_ms(&appdata.now, &link->link_stats.stats.last_time);
+      if (diffms >= pref.link_timeout_time) {
+        /* link expired, remove */
+        GList * *delete_list = (GList * *)delete_list_ptr;
 
+        /* adds current to list of links to delete */
+        *delete_list = g_list_prepend(*delete_list, link_id);
+
+        g_log(G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, _("Queuing link for remove"));
+      }
     }
-  else
-    {
-      /* no packets remaining on link - if link expiration active, see if the
-       * link is expired */
-      if (pref.link_timeout_time)
-        {
-          diffms = subtract_times_ms(&appdata.now, &link->link_stats.stats.last_time);
-          if (diffms >= pref.link_timeout_time)
-            {
-              /* link expired, remove */
-              GList **delete_list = (GList **)delete_list_ptr;
-        
-              /* adds current to list of links to delete */
-              *delete_list = g_list_prepend( *delete_list, link_id);
-    
-              g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,_("Queuing link for remove"));
-            }
-        }
-    }
+  }
 
   return FALSE;
 }
@@ -224,22 +210,21 @@ update_link(link_id_t* link_id, link_t * link, gpointer delete_list_ptr)
 /* links catalog compare function */
 static gint links_catalog_compare(gconstpointer a, gconstpointer b, gpointer dummy)
 {
-  return link_id_compare( (const link_id_t *)a,  (const link_id_t *)b);
+  return link_id_compare((const link_id_t *)a,  (const link_id_t *)b);
 }
 
 /* initializes the catalog */
 void links_catalog_open(void)
 {
   g_assert(!all_links);
-  all_links = g_tree_new_full(links_catalog_compare, NULL, NULL, 
+  all_links = g_tree_new_full(links_catalog_compare, NULL, NULL,
                               (GDestroyNotify)link_delete);
 }
 
 /* closes the catalog, releasing all links */
 void links_catalog_close(void)
 {
-  if (all_links)
-  {
+  if (all_links) {
     g_tree_destroy(all_links);
     all_links = NULL;
   }
@@ -250,16 +235,15 @@ void links_catalog_insert(link_t *new_link)
 {
   g_assert(all_links);
   g_assert(new_link);
- 
-  g_tree_insert (all_links, &new_link->link_id, new_link);
 
-  if (DEBUG_ENABLED)
-  {
+  g_tree_insert(all_links, &new_link->link_id, new_link);
+
+  if (DEBUG_ENABLED) {
     gchar *str = link_id_node_names(&new_link->link_id);
 
-    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_INFO,
-            _("New link: %s. Number of links %d"),
-            str, links_catalog_size());
+    g_log(G_LOG_DOMAIN, G_LOG_LEVEL_INFO,
+          _("New link: %s. Number of links %d"),
+          str, links_catalog_size());
     g_free(str);
   }
 }
@@ -270,7 +254,7 @@ void links_catalog_remove(const link_id_t *key)
   g_assert(all_links);
   g_assert(key);
 
-  g_tree_remove (all_links, key);
+  g_tree_remove(all_links, key);
 }
 
 /* finds a link */
@@ -280,7 +264,7 @@ link_t *links_catalog_find(const link_id_t *key)
   if (!all_links)
     return NULL;
 
-  return g_tree_lookup (all_links, key);
+  return g_tree_lookup(all_links, key);
 }
 
 /* finds a link, creating one if necessary */
@@ -291,8 +275,7 @@ link_t *links_catalog_find_create(const link_id_t *key)
   g_assert(key);
 
   link = links_catalog_find(key);
-  if (!link)
-  {
+  if (!link) {
     link = link_create(key);
     links_catalog_insert(link);
   }
@@ -305,10 +288,10 @@ gint links_catalog_size(void)
   if (!all_links)
     return 0;
 
-  return g_tree_nnodes (all_links);
+  return g_tree_nnodes(all_links);
 }
 
- /* calls the func for every link */
+/* calls the func for every link */
 void links_catalog_foreach(GTraverseFunc func, gpointer data)
 {
   if (!all_links)
@@ -318,10 +301,9 @@ void links_catalog_foreach(GTraverseFunc func, gpointer data)
 }
 
 /* Calls update_link for every link. This is actually a function that
- shouldn't be called often, because it might take a very long time 
+ shouldn't be called often, because it might take a very long time
  to complete */
-void
-links_catalog_update_all(void)
+void links_catalog_update_all(void)
 {
   GList *delete_list = NULL;
 
@@ -330,23 +312,22 @@ links_catalog_update_all(void)
 
   /* we can't delete links while traversing the catalog, so while updating links
    * we fill a list with the expired link_id's */
-  links_catalog_foreach((GTraverseFunc) update_link, &delete_list);
+  links_catalog_foreach((GTraverseFunc)update_link, &delete_list);
 
-  /* after, remove all links on the list from catalog 
+  /* after, remove all links on the list from catalog
    * WARNING: after this call, the list items are also destroyed */
   g_list_foreach(delete_list, gfunc_remove_link, NULL);
-  
+
   /* free the list - list items are already destroyed */
   g_list_free(delete_list);
 
-  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
-         _("Updated links. Active links %d"), links_catalog_size());
+  g_log(G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
+        _("Updated links. Active links %d"), links_catalog_size());
 }
 
 /* adds a new packet to the link, creating it if necessary */
-void
-links_catalog_add_packet(const link_id_t *link_id, packet_info_t * packet, 
-                         packet_direction direction)
+void links_catalog_add_packet(const link_id_t *link_id, packet_info_t *packet,
+                              packet_direction direction)
 {
   link_t *link;
 
@@ -360,9 +341,9 @@ static gboolean link_dump_tvs(gpointer key, gpointer value, gpointer data)
 {
   gchar *msg_link;
   gchar *tmp;
-  gchar **msg = (gchar **)data;
+  gchar * *msg = (gchar * *)data;
   const link_t *link = (const link_t *)value;
-  
+
   msg_link = link_dump(link);
   tmp = *msg;
   *msg = g_strdup_printf("%slink %p:\n%s\n", tmp, link, msg_link);
